summaryrefslogtreecommitdiff
path: root/test/unit/util/real_algebraic_number_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/util/real_algebraic_number_black.cpp')
-rw-r--r--test/unit/util/real_algebraic_number_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/util/real_algebraic_number_black.cpp b/test/unit/util/real_algebraic_number_black.cpp
index 97bbb438c..4300b709c 100644
--- a/test/unit/util/real_algebraic_number_black.cpp
+++ b/test/unit/util/real_algebraic_number_black.cpp
@@ -9,15 +9,15 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::RealAlgebraicNumber.
**
** Black box testing of CVC4::RealAlgebraicNumber.
**/
#include "test.h"
#include "util/real_algebraic_number.h"
-namespace CVC4 {
+namespace CVC5 {
namespace test {
#ifndef CVC4_POLY_IMP
@@ -81,4 +81,4 @@ TEST_F(TestUtilBlackRealAlgebraicNumber, arithmetic)
ASSERT_EQ(msqrt2 * sqrt2, RealAlgebraicNumber(Integer(-2)));
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,15 +9,15 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::RealAlgebraicNumber.
+ ** \brief Black box testing of CVC5::RealAlgebraicNumber.
**
@@ -9,15 +9,15 @@
**
- ** Black box testing of CVC4::RealAlgebraicNumber.
+ ** Black box testing of CVC5::RealAlgebraicNumber.
**/
#include "test.h"